set more off
capture log close
version 9.2

*******************************************************************************
* Purpose:																	  *
* The purpose this do file is to model panel data to estimate the relationship* 
* between EDB revenue and GDP (see Attachment H)                             *
*******************************************************************************

/*

The do file uses 2 different sources of revenue, namely:
	(a) revenue based on information disclosure (ID) information (this is referred to as "ID revenue" in this do file)
	(b) revenue based on 53zd information request (this is referred to as "53zd revenue" in this do file) 

The do file models the natural logarithm of GDP and revenue

The preferred model is the random effects model (cross section for suppliers) based on ID revenue

The main inputs used for each model section is summarised below:
	(a) panel model based on ID revenue and regional gdp, by EDB: "edb_revenue1.data"
	(b) panel model based on 53zd revenue and regional gdp, by EDB: "53zd_revenue_gdp.data"
	
This do file uses a few tests that are not installed by default in stata 9.2 so need to install that first: 

	xttest3 implemented by Baum http://www.stata-journal.com/software/sj4-2/st0004_2/xttest2.hlp:

	xtserial implemented by Drukker http://www.stata-journal.com/software/sj3-2

*/
*******************
***start do file***
*******************

*Change file path to where data is stored
cd [insert filepath]

capture log using model.log, replace

***********************************************************************
***(a) regression based on panel data based on ID revenue, 2004-2011***
***********************************************************************

*use ID revenue and regional GDP as discussed in the "Data used for our analysis" section in Attachment H*
use edb_revenue1.dta, clear

*Section A: Some tidying of dataset before modelling*

drop _merge

keep if year>2003

********************************
***generate weight variables***
*******************************

***insert calculation of revenue shares for purposes to test the effect of a weighthed regression approach

*insert total net real revenue for each year
gen total_revenue= 11708856 if year==2004
replace total_revenue=11678399 if year==2005
replace total_revenue=11649188 if year==2006
replace total_revenue=11618787 if year==2007
replace total_revenue=11588206 if year==2008
replace total_revenue=11648213 if year==2009
replace total_revenue=11766983 if year==2010
replace total_revenue=11881278 if year==2011

*generate revenue shares to use as weight variable
gen share= net_revenue_real/ total_revenue

*generate constant revenue shares over time.  
gen share_constant= net_revenue_real/ total_revenue if year==2004
replace share_constant= share_constant[_n-1] if share_constant== .

*********************************************
*** declare the dataset as a panel dataset***
*********************************************

sort edb year
xtset edb year

********************************
* Statistical outlier programme*
********************************
* define here, but is used only further below

capture program drop test_outlier

program define test_outlier

predict yhattt, xb
predict e, residuals
*dfbeta - slope change resulting from exclusion of observation
predict lev, leverage
predict dfits, dfits
predict wd, welsch
predict cooksd, cooksd

/*e(N) = sample size, k = no. of independent variables including constant*/

gen k = e(df_m) + 1 


list edb dfits if abs(dfits)>2*sqrt(k/e(N))
/*By DFITS-attempts to summarize the information in the leverage versus residual-squared plot into a single statistic*/

list edb cooksd if abs(cooksd)>4/e(N)
/*By Cook's Distance is function of DFITS, is a metric for deciding whether a particular point alone affects regression estimates much*/

list edb wd if abs(wd)>3*sqrt(k)
/*By Welsch's Distance is function of DFITS*/

list edb lev if lev>((2*k)/e(N))
/*By Leverage refers to the influence of observations on the estimated relationship and is the most common statistic employed to identify such observations*/



gen g1=1 if abs(dfits)>2*sqrt(k/e(N)) 
gen dfits_outlier_stat=abs(dfits)
scatter e yhattt , msize(small) scale(0) || scatter e yhattt if g1==1, mcolor(red) ///
msymbol() msize(small) yline(0) || scatter e yhattt if g1==1, mcolor(red) msymbol() ///
msize(small) yline(0) mlabel(edb) mlabcolor(blue) ///
saving(DFITS, replace)


gen g2=1 if abs(cooksd)>4/e(N)
gen cooksd_outlier_stat=abs(cooksd)
scatter e yhattt, msize(small) scale(0) || scatter e yhattt if g2==1, ///
mcolor(red) msymbol() msize(small) yline(0) || scatter e yhattt if g2==1, mcolor(red) ///
msymbol() msize(small) yline(0) mlabel(edb) mlabcolor(blue) ///
saving(Cooks_distance, replace)

gen g3=1 if abs(wd)>3*sqrt(k)
gen wd_outlier_stat=abs(wd)
scatter e yhattt, msize(small) scale(0) || scatter e yhattt if g3==1, mcolor(red) ///
msymbol() msize(small) yline(0) || scatter e yhattt if g3==1, mcolor(red) ///
msymbol() msize(small) yline(0) mlabel(edb) mlabcolor(blue) ///
saving(Welsch_distance, replace)


gen g4=1 if lev>((2*k)/e(N))
gen lev_outlier_stat=abs(lev)
scatter e yhattt, msize(small) scale(0) || scatter e yhattt if g4==1, mcolor(red) ///
msymbol() msize(small) yline(0) || scatter e yhattt if g4==1, mcolor(red) ///
msymbol() msize(small) yline(0) mlabel(edb) mlabcolor(blue) ///
saving(leverage, replace)

drop yhattt e lev dfits wd cooksd k 


end

*****************************************************
*Test for outliers in pooled model using ID revenue *
*****************************************************
reg lnrev lngdp1
test_outlier

foreach var in g1 g2 g3 g4 {
	replace `var' = 0 if `var' == .
	}
gen sum_outlier = g1 + g2 + g3 + g4

label var sum_outlier "Indicates if observation a potential outlier"

list edb year sum_outlier if sum_outlier > 1
*-> suggest Vector might be an outlier. Run model excluding Vector.

reg lnrev lngdp1, robust
reg lnrev lngdp1 if edb !=16 , robust
reg lnrev lngdp if edb ==16 , robust

*-> coefficient is statistically different. Exclude Vector from estimation

drop g1 g2 g3 g4  dfits_outlier_stat cooksd_outlier_stat wd_outlier_stat lev_outlier_stat sum_outlier 


****************************************************************************************************
***drop EDBs as outlined in table  "Observations we excluded from our modelling" in Attachment H***
****************************************************************************************************


*** drop Orion==9, year 2011 because no data is available for the Orion network in 2011- Orion were granted an exemption ID in 2011*** 
drop if edb == 9 & year==2011

***2009 data for Vector==16 and Wellington==17 was excluded from the analysis. The sale of the Wellington network mid-way through 2009 could distort the analysis*** 
drop if edb== 17 & year==2009
drop if edb== 16 & year==2009

****after reviewing the data and drop in year 2009 for Wellington, it is better to drop Wellington as only two observations points are left for Wellington***
drop if edb==17 

***after reviewing the data visually, it is better to drop Otago==10 and Aurora==3 becuase it is a disproportional influence in the results (see Chart 1 in Attachment H)
drop if edb==10 
drop if edb==3

****after reviewing the data, drop Vector==16 becuase it is an outlier (see impact of outlier test above)
drop if edb== 16


*Section B: Modelling*

*****************
***Pooled OLS***
*****************

*run pooled model- see Table 2 "Pooled model" for results in Attachment H*
regress lnrev lngdp1

*test effect of a weighted regression based on variable revenue shares as the weight variable
regress lnrev lngdp1 [aw=share]

*test effect of a weighted regression based on constant revenue shares as the weight variable
regress lnrev lngdp1 [aw= share_constant]

***************************************
***test for poolablity (Roy-Zellner****
***************************************

*test poolability for cross-section effects

xi,prefix(E) i.edb
gen Eedb_1=1 if edb==1
replace Eedb_1=0 if edb!=1
foreach var of varlist  lngdp1 {
foreach num of numlist 1 2 4 5 6 7 8 9 11 12 13 14 15 {
gen `var'_`num'=`var'*Eedb_`num'
}
}
quietly xtreg  lnrev lngdp1_*, re
test ( lngdp1_1= lngdp1_2= lngdp1_4= lngdp1_5= lngdp1_6= lngdp1_7= lngdp1_8= lngdp1_9= lngdp1_11= lngdp1_12= lngdp1_13= lngdp1_14= lngdp1_15)

*results provided in Table 3 "Results of diagnostic tests"  in test on poolability (cross-sections) in Attachment H

*test poolability for time effects (see below, after two-way random effects model)


*****************************************************************
***One-way error Fixed effects model (cross-sectional effects)***
*****************************************************************

*run fixed effects model (cross sections)- see Table 2 "Fixed effects model (cross sections)" for results in Attachment H*
xtreg lnrev lngdp1, fe 
estimates store fixed
matrix bW=get(_b)
matrix vW=get(VCE)
xttest3

*test effect of a weighted regression based on variable revenue shares as the weight variable
areg  lnrev lngdp1[aw= share], absorb( edb)

*test effect of a weighted regression based on constant revenue shares as the weight variable
areg  lnrev lngdp1[aw= share_constant], absorb( edb)

**test for edb specific effects***

regress lnrev lngdp1 Eedb_*,noconstant
testparm Eedb_*

*results provided in Table 3 "Results of diagnostic tests"  in test on fixed effects (cross-sections) in Attachment H


*******************************************************
***One-way error Fixed effects model (time effects)****
*******************************************************
xi,prefix(Y) i.year
gen Yyear_2004=1 if year==2004
replace Yyear_2004=0 if year!=2004
rename  Yyear_2004 Yyear_1 
rename  Yyear_2005 Yyear_2
rename  Yyear_2006 Yyear_3
rename  Yyear_2007 Yyear_4
rename  Yyear_2008 Yyear_5
rename  Yyear_2009 Yyear_6
rename  Yyear_2010 Yyear_7
rename  Yyear_2011 Yyear_8

regress lnrev lngdp1 Yyear_*, robust

**test for time specific effects***

regress lnrev lngdp1 Yyear_*,noconstant
testparm Yyear_*

*results provided in Table 3 "Results of diagnostic tests"  in test on fixed effects (time effects) in Attachment H

****************************************
***Two-way error Fixed effects model****
****************************************

reg  lnrev  lngdp1 Eedb_*  Yyear_*, robust 

****************************************************
***One-way error Between effects (cross sections)***
****************************************************

*run between effects model (cross sections)- see Table 2 "Between effects model (cross sections)" for results in Attachment H*
xtreg lnrev lngdp1, be
matrix bB=get(_b)
matrix vB=get(VCE)

**************************************************
***One-way error Random effects (cross sections)**
**************************************************

*run random effects model (cross sections)- see Table 2 "Random effects model (cross sections)" for results in Attachment H*
*this is the preferred model
xtreg lnrev lngdp1, re robust
estimates store random

***test random effects***
xttest0
xtserial lnrev lngdp1 
*results provided in Table 3 "Results of diagnostic tests"  in test on LM on random effect (cross sections) in Attachment H

***test random vs fixed effects***
hausman fixed random
hausman fixed random,sigmamore

***if p-value insignificant, prob>Chi larger 0.5 then use random effects, if p-value significant- use fixed effect model***
*results provided in Table 3 "Results of diagnostic tests"  in test on fixed vs random effects (cross-section) in Attachment H

****************************************
***Two-way error Random effects model****
****************************************

xtmixed  lnrev  lngdp1 || _all: R.edb || _all: R.year

**********************************
*test poolability for time effects
**********************************

use edb_revenue1.dta, clear
drop _merge

keep if year>2003
*** drop Orion==9, year 2011 because no data is available for the Orion network in 2011- Orion were granted an exemption ID in 2011*** 
drop if edb == 9 & year==2011

***2009 data for Vector==16 and Wellington==17 was excluded from the analysis. The sale of the Wellington network mid-way through 2009 could distort the analysis*** 
drop if edb== 17 & year==2009
drop if edb== 16 & year==2009

****after reviewing the data and drop in year 2009 for Wellington, it is better to drop Wellington as only two observations points are left for Wellington***
drop if edb==17 

***after reviewing the data visually, it is better to drop Otago==10 and Aurora==3 becuase it is a disproportional influence in the results (see Chart 1 in Attachment H)
drop if edb==10 
drop if edb==3

****after reviewing the data, drop Vector==16 becuase it is an outlier (see impact of outlier test above)
drop if edb== 16

xi,prefix(Y) i.year
gen Yyear_2004=1 if year==2004
replace Yyear_2004=0 if year!=2004
rename  Yyear_2004 Yyear_1 
rename  Yyear_2005 Yyear_2
rename  Yyear_2006 Yyear_3
rename  Yyear_2007 Yyear_4
rename  Yyear_2008 Yyear_5
rename  Yyear_2009 Yyear_6
rename  Yyear_2010 Yyear_7
rename  Yyear_2011 Yyear_8


foreach var of varlist  lngdp1 {
foreach num of numlist 1(1)8{
gen `var'_`num'=`var'*Yyear_`num'
}
}

quietly xtreg  lnrev lngdp1_*, re i(year)
test ( lngdp1_1= lngdp1_2= lngdp1_3= lngdp1_4= lngdp1_5= lngdp1_6= lngdp1_7= lngdp1_8)

*results provided in Table 3 "Results of diagnostic tests"  on test on poolability (time effects) in Attachment H


************************************************
***One-way error Random effects (time effects)**
************************************************

*run random effects model (time effects)- see Table 2 "Random effects model (time effects)" for results in Attachment H*
xtreg lnrev lngdp1, re i(year)robust
estimates store random

***test random effects***
xttest0
*results provided in Table 3 "Results of diagnostic tests"  on test LM on random effect (time) in Attachment H


************************************************
***One-way error fixed effects (time effects)**
************************************************

*run fixed effects model (time effects)- see Table 2 "Fixed effects model (time effects)" for results in Attachment H*
xtreg lnrev lngdp1, fe i(year) robust
estimates store fixed

***test random vs fixed effects***
hausman fixed random
*results provided in Table 3 "Results of diagnostic tests"  in test on fixed vs random effects (time) in Attachment H

************************************************
***One-way error between effects (time effects)**
************************************************

*run between effects model (time effects)- see Table 2 "Between effects model (time effects)" for results in Attachment H*
xtreg lnrev lngdp1, be i(year)


*************************************************************************
*** (b)regression based on panel data based on 53zd revenue, 2008-2011***                                                                         *
*************************************************************************

*use 53ZD revenue and regional GDP as discussed in the "Data used for our analysis" section in Attachment H*
use 53zd_revenue_gdp.dta, clear


*Section A: Some tidying of dataset before modelling*

********************************
***generate weight variables***
*******************************

***insert calculation of revenue shares for purposes to test the effect of a weighted regression approach

*insert total ic_linechargerev_000 for each year
gen total_ic_revenue= 493170 if year==2008
replace total_ic_revenue=500654 if year==2009
replace total_ic_revenue=536383 if year==2010
replace total_ic_revenue=523832 if year==2011

*generate revenue shares to use as weight variable
gen share= ic_linechargerev_000/ total_ic_revenue

*generate constant revenue shares over time.  
gen share_constant= ic_linechargerev_000/ total_ic_revenue if year==2008
replace share_constant= share_constant[_n-1] if share_constant== .

*********************************************
*** declare the dataset as a panel dataset***
*********************************************

sort edb year
xtset edb year

**************************
*** impact of outliers ***
**************************

capture program drop test_outlier

program define test_outlier

predict yhattt, xb
predict e, residuals
*dfbeta				/*Slope change resulting from exclusion of observation*/
predict lev, leverage
predict dfits, dfits
predict wd, welsch
predict cooksd, cooksd

/*e(N) = sample size, k = no. of independent variables including constant*/

gen k = e(df_m) + 1 


list edb dfits if abs(dfits)>2*sqrt(k/e(N))
/*By DFITS-attempts to summarize the information in the leverage versus residual-squared plot into a single statistic*/

list edb cooksd if abs(cooksd)>4/e(N)
/*By Cook's Distance is function of DFITS, is a metric for deciding whether a particular point alone affects regression estimates much*/

list edb wd if abs(wd)>3*sqrt(k)
/*By Welsch's Distance is function of DFITS*/

list edb lev if lev>((2*k)/e(N))
/*By Leverage refers to the influence of observations on the estimated relationship and is the most common statistic employed to identify such observations*/



gen g1=1 if abs(dfits)>2*sqrt(k/e(N)) 
gen dfits_outlier_stat=abs(dfits)
scatter e yhattt , msize(small) scale(0) || scatter e yhattt if g1==1, mcolor(red) ///
msymbol() msize(small) yline(0) || scatter e yhattt if g1==1, mcolor(red) msymbol() ///
msize(small) yline(0) mlabel(edb) mlabcolor(blue) ///
saving(DFITS, replace)


gen g2=1 if abs(cooksd)>4/e(N)
gen cooksd_outlier_stat=abs(cooksd)
scatter e yhattt, msize(small) scale(0) || scatter e yhattt if g2==1, ///
mcolor(red) msymbol() msize(small) yline(0) || scatter e yhattt if g2==1, mcolor(red) ///
msymbol() msize(small) yline(0) mlabel(edb) mlabcolor(blue) ///
saving(Cooks_distance, replace)

gen g3=1 if abs(wd)>3*sqrt(k)
gen wd_outlier_stat=abs(wd)
scatter e yhattt, msize(small) scale(0) || scatter e yhattt if g3==1, mcolor(red) ///
msymbol() msize(small) yline(0) || scatter e yhattt if g3==1, mcolor(red) ///
msymbol() msize(small) yline(0) mlabel(edb) mlabcolor(blue) ///
saving(Welsch_distance, replace)


gen g4=1 if lev>((2*k)/e(N))
gen lev_outlier_stat=abs(lev)
scatter e yhattt, msize(small) scale(0) || scatter e yhattt if g4==1, mcolor(red) ///
msymbol() msize(small) yline(0) || scatter e yhattt if g4==1, mcolor(red) ///
msymbol() msize(small) yline(0) mlabel(edb) mlabcolor(blue) ///
saving(leverage, replace)

drop yhattt e lev dfits wd cooksd k 


end

reg lnrev_ic lngdp
test_outlier

foreach var in g1 g2 g3 g4 {
	replace `var' = 0 if `var' == .
	}

gen sum_outlier = g1 + g2 + g3 + g4

label var sum_outlier "Indicates if observation a potential outlier"

list edb year sum_outlier if sum_outlier > 1
*-> suggest Vector might be an outlier. Run model excluding Vector.

reg lnrev_ic lngdp, robust
reg lnrev_ic lngdp if edb !=16 , robust
reg lnrev_ic lngdp if edb ==16 , robust

*-> coefficient is statistically different. Consider to exclude Vector

drop g1 g2 g3 g4  dfits_outlier_stat cooksd_outlier_stat wd_outlier_stat lev_outlier_stat sum_outlier 

***************
***drop EDBs***
***************

*** drop Orion in year 2011 because no data is available for the Orion network in 2011- Orion were granted an exemption from ID in 2011 following 2010 earthquakedrop if edb=="Orion" & year==2011
drop if  edb  == 9 & year==2011

***2009 data for Vector==16 and Wellington==17 was excluded from the analysis. The sale of the Wellington network mid-way through 2009 could distort the analysis*** 
drop if edb == 17 & year == 2008 
drop if edb == 17 & year == 2009 
drop if edb == 16 & year==2009

***after reviewing the data visually, it is better to drop Aurora==3 becuase it is a disproportional influence in the results (see Chart 1 in Attachment H)
drop if edb==3

****after reviewing the data, drop Vector==16 becuase it is an outlier (see impact of outlier test above)
drop if edb== 16

***note there is no evidence to suggest that we need to exclude Otago from the 53ZD data for estimation

*Section B: Modelling*

*****************
***Pooled OLS***
*****************

*run pooled model- see Table 3 "Pooled model" for results in Attachment H*
regress lnrev_ic lngdp

*test effect of a weighted regression based on variable revenue shares as the weight variable
regress lnrev_ic lngdp [aw=share]

*test effect of a weighted regression based on constant revenue shares as the weight variable
regress lnrev_ic lngdp [aw= share_constant]

******************************************
***test for poolablity on cross sections**
******************************************

xi,prefix(E) i.edb
gen Eedb_1=1 if edb==1
replace Eedb_1=0 if edb!=1
foreach var of varlist  lngdp {
foreach num of numlist 1 2 4 5 6 7 8 9 10 11 12 13 14 15 17 {
gen `var'_`num'=`var'*Eedb_`num'
}
}
quietly xtreg  lnrev_ic lngdp_*, re
test ( lngdp_1= lngdp_2= lngdp_4= lngdp_5= lngdp_6= lngdp_7= lngdp_8= lngdp_9= lngdp_10= lngdp_11= lngdp_12= lngdp_13= lngdp_14= lngdp_15= lngdp_17)

*regress individual regressions for time effects-later with Roy-Zellner

*****************************************************************
***One-way error Fixed effects model (cross-sectional effects)***
*****************************************************************

*run fixed effects model- see Table 3 "Fixed effects model (cross sections)" for results in Attachment H*
xtreg lnrev_ic lngdp, fe robust
estimates store fixed
matrix bW=get(_b)
matrix vW=get(VCE)
xttest3

*test effect of a weighted regression based on variable revenue shares as the weight variable
areg  lnrev_ic lngdp [aw= share], absorb( edb)

*test effect of a weighted regression based on constant revenue shares as the weight variable
areg  lnrev_ic lngdp [aw= share], absorb( edb)

**test for edb specific effects***

regress lnrev_ic lngdp  Eedb_*,noconstant
testparm Eedb_*


*******************************************************
***One-way error Fixed effects model (time effects)****
*******************************************************
xi,prefix(Y) i.year
gen Yyear_2008=1 if year==2008
replace Yyear_2008=0 if year!=2008
rename  Yyear_2008 Yyear_1 
rename  Yyear_2009 Yyear_2
rename  Yyear_2010 Yyear_3
rename  Yyear_2011 Yyear_4

regress lnrev_ic lngdp  Yyear_* 
scalar RRSTIME=_result(4)

**test for time specific effects***

regress lnrev_ic lngdp Yyear_*,noconstant
testparm Yyear_*

****************************************
***Two-way error Fixed effects model****
****************************************

reg  lnrev_ic  lngdp Eedb_*  Yyear_*, robust 


*********************************************************
***One-way error Between effects model (cross sections)***
*********************************************************

*run between effects model- see Table 3 "Between effects model (cross sections)" for results in Attachment H*
xtreg lnrev_ic lngdp, be
matrix bB=get(_b)
matrix vB=get(VCE)

*************************************************
***One-way error Random effects (cross sections)**
*************************************************

*run random effects model- see Table 3 "Random effects model (cross sections)" for results in Attachment H*
xtreg lnrev_ic lngdp, re robust
estimates store random

***test random effects***
xttest0
xtserial lnrev_ic lngdp

***test random vs fixed effects***
hausman fixed random
hausman fixed random,sigmamore

***if p-value insignificant, prob>Chi larger 0.5 then use random effects, if p-value significant- use fixed effect model***

****************************************
***Two-way error Random effects model****
****************************************

xtmixed  lnrev_ic  lngdp || _all: R.edb || _all: R.year


*************************************
*test poolability for time effects***
*************************************

use 53zd_revenue_gdp.dta, clear

*** drop Orion in year 2011 because no data is available for the Orion network in 2011- Orion were granted an exemption from ID in 2011 following 2010 earthquakedrop if edb=="Orion" & year==2011
drop if  edb  == 9 & year==2011

***2009 data for Vector==16 and Wellington==17 was excluded from the analysis. The sale of the Wellington network mid-way through 2009 could distort the analysis*** 
drop if edb == 17 & year == 2008 
drop if edb == 17 & year == 2009 
drop if edb == 16 & year==2009

***after reviewing the data visually, it is better to drop Aurora==3 becuase it is a disproportional influence in the results (see Chart 1 in Attachment H)
drop if edb==3

****after reviewing the data, drop Vector==16 becuase it is an outlier (see impact of outlier test above)
drop if edb== 16

***note there is no evidence to suggest that we need to exclude Otago from the 53ZD data for estimation

xi,prefix(Y) i.year
gen Yyear_2008=1 if year==2008
replace Yyear_2008=0 if year!=2008
rename  Yyear_2008 Yyear_1 
rename  Yyear_2009 Yyear_2
rename  Yyear_2010 Yyear_3
rename  Yyear_2011 Yyear_4


foreach var of varlist  lngdp {
foreach num of numlist 1(1)4{
gen `var'_`num'=`var'*Yyear_`num'
}
}

quietly xtreg  lnrev_ic lngdp_*, re i(year)
test ( lngdp_1= lngdp_2= lngdp_3= lngdp_4)

************************************************
***One-way error Random effects (time effects)**
************************************************

*run random effects model (time effects)- see Table 3 "Random effects model (time effects)" for results in Attachment H*
xtreg lnrev_ic lngdp, re i(year)robust
estimates store random
xttest0

************************************************
***One-way error Fixed effects (time effects)**
************************************************

*run fixed effects model (time effects)- see Table 3 "Fixed effects model (time effects)" for results in Attachment H*

xtreg lnrev_ic lngdp, fe i(year)
estimates store fixed

***test random vs fixed effects***
hausman fixed random

************************************************
***One-way error Between effects (time effects)**
************************************************

*run between effects model (time effects)- see Table 3 "Between effects model (time effects)" for results in Attachment H*
xtreg lnrev_ic lngdp, be i(year)




capture log close


